"""It Happens

A Python package for creating your own Shit Happens playing cards.
"""

from ithappens.style.styles.registration import _register
from ithappens.style.fonts.manage import _add_fonts

_add_fonts()
_register()
